@@ -4,14 +4,14 @@ from typing import Optional
 from telescope_sdk.common import UserFacingDataType
 
 
-class RecommendationStatus(Enum):
+class RecommendationStatus(str, Enum):
     ACCEPTED = 'ACCEPTED'
     REJECTED = 'REJECTED'
     SAVED = 'SAVED'
     PENDING = 'PENDING'
 
 
-class RecommendationRejectionReason(Enum):
+class RecommendationRejectionReason(str, Enum):
     NOT_RELEVANT = 'NOT_RELEVANT'
     WRONG_POSITION_RIGHT_COMPANY = 'WRONG_POSITION_RIGHT_COMPANY'
     RIGHT_POSITION_WRONG_COMPANY = 'RIGHT_POSITION_WRONG_COMPANY'
